@@ -14,9 +14,8 @@ for (strategy in strategies) {
 
   res <- tryCatch({
     foreach(i = 1:10, .errorhandling = "stop") %dopar% {
-      set.seed(0xBEEF)
       if (i %% 2 == 0) stop(sprintf("Index error ('stop'), because i = %d", i))
-      rnorm(i, mean = mu, sd = sigma)
+      dnorm(i, mean = mu, sd = sigma)
     }
   }, error = identity)
   print(res)
@@ -38,9 +37,8 @@ for (strategy in strategies) {
   mu <- 1.0
   sigma <- 2.0
   res <- foreach(i = 1:10, .errorhandling = "pass") %dopar% {
-    set.seed(0xBEEF)
     if (i %% 2 == 0) stop(sprintf("Index error ('pass'), because i = %d", i))
-    rnorm(i, mean = mu, sd = sigma)
+    dnorm(i, mean = mu, sd = sigma)
   }
   str(res)
 
@@ -59,9 +57,8 @@ for (strategy in strategies) {
   mu <- 1.0
   sigma <- 2.0
   res <- foreach(i = 1:10, .errorhandling = "remove") %dopar% {
-    set.seed(0xBEEF)
     if (i %% 2 == 0) stop(sprintf("Index error ('remove'), because i = %d", i))
-    rnorm(i, mean = mu, sd = sigma)
+    dnorm(i, mean = mu, sd = sigma)
   }
   str(res)
 
